@@ -25,6 +25,7 @@ class QScrollArea;
 class QGridLayout;
 class ValueSelector;
 class QSpinBox;
+class NetworkProxyDialog;
 
 class SettingsDialog : public AbstractDialog
 {
@@ -40,11 +41,15 @@ private:
 private slots:
     void loadSettings();
     void saveSettings();
+
+    void showNetworkProxyDialog();
     
 private:
     ValueSelector *m_orientationSelector;
     ValueSelector *m_languageSelector;
 
+    QPushButton *m_proxyButton;
+
     QSpinBox *m_sleepTimerSpinBox;
 
     QDialogButtonBox *m_buttonBox;
@@ -52,6 +57,8 @@ private:
     QScrollArea *m_scrollArea;
 
     QGridLayout *m_grid;
+
+    NetworkProxyDialog *m_proxyDialog;
 };
 
 #endif // SETTINGSDIALOG_H
